summaryrefslogtreecommitdiffstats
path: root/ksplashml/wndmain.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 10:49:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 10:49:49 -0600
commitdc5f267664506a312203c26bfe9001a448b0bb0f (patch)
treea78c7f15e87303d22b89619db42fc56ad8f4a046 /ksplashml/wndmain.cpp
parent98f4a055baf6eb7ea5c3d69d6a3f2162b491e253 (diff)
downloadtdebase-dc5f267664506a312203c26bfe9001a448b0bb0f.tar.gz
tdebase-dc5f267664506a312203c26bfe9001a448b0bb0f.zip
Rename KLock and KTrader to avoid conflicts with KDE4
Diffstat (limited to 'ksplashml/wndmain.cpp')
-rw-r--r--ksplashml/wndmain.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/ksplashml/wndmain.cpp b/ksplashml/wndmain.cpp
index 4cbfc2513..e889a2f4b 100644
--- a/ksplashml/wndmain.cpp
+++ b/ksplashml/wndmain.cpp
@@ -346,7 +346,7 @@ void KSplash::loadTheme( const TQString& theme )
ThemeEngine *KSplash::_loadThemeEngine( const TQString& pluginName, const TQString& theme )
{
// Since we may be called before the DCOP server is active, we cannot use the KTrader framework for obtaining plugins. In its
// place, we use the following naive heuristic to locate plugins. If we are not in managed mode, and we are not in testing mode
// either, we assume that we have been called by starttde. In this case, we simply try to load the library whose name should
// conform to the following specification:
@@ -369,7 +369,7 @@ ThemeEngine *KSplash::_loadThemeEngine( const TQString& pluginName, const TQStri
else
{
// Fancier way of locating plugins.
- KService::List list= KTrader::self()->query("KSplash/Plugin", TQString("[X-KSplash-PluginName] == '%1'").arg(pluginName));
+ KService::List list= TDETrader::self()->query("KSplash/Plugin", TQString("[X-KSplash-PluginName] == '%1'").arg(pluginName));
KService::Ptr ptr;
if (!list.isEmpty())
{
@@ -346,7 +346,7 @@ void KSplash::loadTheme( const TQString& theme )
ThemeEngine *KSplash::_loadThemeEngine( const TQString& pluginName, const TQString& theme )
{
- // Since we may be called before the DCOP server is active, we cannot use the KTrader framework for obtaining plugins. In its
+ // Since we may be called before the DCOP server is active, we cannot use the TDETrader framework for obtaining plugins. In its
// place, we use the following naive heuristic to locate plugins. If we are not in managed mode, and we are not in testing mode
// either, we assume that we have been called by starttde. In this case, we simply try to load the library whose name should